# sapi_client Library
A unified storage API for all data-storage back-ends.

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.0.3
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install sapi
```
(you may need to run `pip` with root permission: `sudo pip install sapi`, or use a virtual environment)

Then import the package:
```python
import sapi_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import sapi_client
```

## CLI tool

### Configuration file

The CLI tool will try to read a documentation file located in **/etc/sapi/sapi.conf**

```
[api]
host = host-where-the-api-runs.domain.ext
```

### Use

```bash
(test) /t/test sapi
Type:        SapiApi
String form: <sapi_client.apis.sapi_api.SapiApi object at 0x7f331fa8a790>
Docstring:   NOTE: This class is auto generated by the swagger code generator program.
Do not edit the class manually.
Ref: https://github.com/swagger-api/swagger-codegen

Usage:       sapi
             sapi api-client
             sapi delete-export
             sapi delete-export-rule
             sapi delete-export-rule-with-http-info
             sapi delete-export-with-http-info
             sapi delete-locks
             sapi delete-locks-with-http-info
             sapi delete-snapshots
             sapi delete-snapshots-with-http-info
             sapi delete-volume
             sapi delete-volume-with-http-info
             sapi get-all-exports
             sapi get-all-exports-with-http-info
             sapi get-all-locks
             sapi get-all-locks-with-http-info
             sapi get-all-snapshots
             sapi get-all-snapshots-with-http-info
             sapi get-export
             sapi get-export-with-http-info
             sapi get-snapshots
             sapi get-snapshots-with-http-info
             sapi get-volume
             sapi get-volume-with-http-info
             sapi get-volumes
             sapi get-volumes-with-http-info
             sapi patch-volume
             sapi patch-volume-with-http-info
             sapi post-export
             sapi post-export-with-http-info
             sapi post-snapshots
             sapi post-snapshots-with-http-info
             sapi post-volume
             sapi post-volume-with-http-info
             sapi put-export-rule
             sapi put-export-rule-with-http-info
             sapi put-locks
             sapi put-locks-with-http-info
```

```bash
(test) /t/test sapi get-volume --volume-name "dodpinocho03" --subsystem dbnasserver - to-str
{'active_policy_name': 'dbod_11.35.328',
 'aggregate_name': 'aggr1_rac3471',
 'autosize_enabled': True,
 'autosize_increment': None,
 'caching_policy': 'auto',
 'compression_enabled': False,
 'creation_time': datetime.datetime(2017, 2, 8, 16, 38, 55, tzinfo=tzutc()),
 'filer_address': 'dbnasserver',
 'inline_compression': False,
 'junction_path': '/ORA/dbs03/PINOCHO',
 'max_autosize': 53687091200,
 'name': 'dodpinocho03',
 'percentage_snapshot_reserve': 20,
 'percentage_snapshot_reserve_used': 85,m
 'size_total': 16532119552,
 'size_used': 2803556352,
 'state': 'online',
 'uuid': '150e9c72-ee1d-11e6-9e0e-00a098465238'}
```

## Use as Library

An example of how to initialize the authentication and call the methods can be found
in the **examples** folder

[get_volumes](examples/get_volume)

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import sapi_client
from sapi_client.rest import ApiException
from pprint import pprint

# Configure OAuth2 access token for authorization: sso
sapi_client.configuration.access_token = 'YOUR_ACCESS_TOKEN'
# create an instance of the API class
api_instance = sapi_client.StorageApi()
policy = 'policy_example' # str | The policy to operate on
subsystem = 'subsystem_example' # str | The subsystem to run the command on.

try:
    api_instance.delete_export(policy, subsystem)
except ApiException as e:
    print("Exception when calling StorageApi->delete_export: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://localhost/*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*StorageApi* | [**delete_export**](docs/StorageApi.md#delete_export) | **DELETE** /{subsystem}/export/{policy} | 
*StorageApi* | [**delete_export_rule**](docs/StorageApi.md#delete_export_rule) | **DELETE** /{subsystem}/export/{policy}/{rule} | 
*StorageApi* | [**delete_locks**](docs/StorageApi.md#delete_locks) | **DELETE** /{subsystem}/volumes/{volume_name}/locks/{host} | 
*StorageApi* | [**delete_snapshots**](docs/StorageApi.md#delete_snapshots) | **DELETE** /{subsystem}/volumes/{volume_name}/snapshots/{snapshot_name} | 
*StorageApi* | [**delete_volume**](docs/StorageApi.md#delete_volume) | **DELETE** /{subsystem}/volumes/{volume_name} | 
*StorageApi* | [**get_all_exports**](docs/StorageApi.md#get_all_exports) | **GET** /{subsystem}/export | 
*StorageApi* | [**get_all_locks**](docs/StorageApi.md#get_all_locks) | **GET** /{subsystem}/volumes/{volume_name}/locks | 
*StorageApi* | [**get_all_snapshots**](docs/StorageApi.md#get_all_snapshots) | **GET** /{subsystem}/volumes/{volume_name}/snapshots | 
*StorageApi* | [**get_export**](docs/StorageApi.md#get_export) | **GET** /{subsystem}/export/{policy} | 
*StorageApi* | [**get_snapshots**](docs/StorageApi.md#get_snapshots) | **GET** /{subsystem}/volumes/{volume_name}/snapshots/{snapshot_name} | 
*StorageApi* | [**get_volume**](docs/StorageApi.md#get_volume) | **GET** /{subsystem}/volumes/{volume_name} | 
*StorageApi* | [**get_volumes**](docs/StorageApi.md#get_volumes) | **GET** /{subsystem}/volumes | 
*StorageApi* | [**patch_volume**](docs/StorageApi.md#patch_volume) | **PATCH** /{subsystem}/volumes/{volume_name} | 
*StorageApi* | [**post_export**](docs/StorageApi.md#post_export) | **POST** /{subsystem}/export/{policy} | 
*StorageApi* | [**post_snapshots**](docs/StorageApi.md#post_snapshots) | **POST** /{subsystem}/volumes/{volume_name}/snapshots/{snapshot_name} | 
*StorageApi* | [**post_volume**](docs/StorageApi.md#post_volume) | **POST** /{subsystem}/volumes/{volume_name} | 
*StorageApi* | [**put_export_rule**](docs/StorageApi.md#put_export_rule) | **PUT** /{subsystem}/export/{policy}/{rule} | 
*StorageApi* | [**put_locks**](docs/StorageApi.md#put_locks) | **PUT** /{subsystem}/volumes/{volume_name}/locks/{host} | 


## Documentation For Models

 - [ExportPolicy](docs/ExportPolicy.md)
 - [Lock](docs/Lock.md)
 - [OptionalFromSnapshot](docs/OptionalFromSnapshot.md)
 - [PolicyRule](docs/PolicyRule.md)
 - [Snapshot](docs/Snapshot.md)
 - [SnapshotPut](docs/SnapshotPut.md)
 - [VolumeCreate](docs/VolumeCreate.md)
 - [VolumeRead](docs/VolumeRead.md)
 - [VolumeWrite](docs/VolumeWrite.md)


## Documentation For Authorization


## api_key

- **Type**: API key
- **API key parameter name**: api_key
- **Location**: HTTP header

## sso

- **Type**: OAuth
- **Flow**: implicit
- **Authorization URL**: https://it-db-storage-api.web.cern.ch/login
- **Scopes**: 
 - **write**: Creation/Destruction operations
 - **read**: Safe RO operations


## Author



